@@ -1,5 +1,5 @@
-#ifndef __MOBIUS_PYTHON_FILESYSTEM_FILESYSTEM_HFS_H__
-#define __MOBIUS_PYTHON_FILESYSTEM_FILESYSTEM_HFS_H__
+#ifndef MOBIUS_PYTHON_FILESYSTEM_FILESYSTEM_HFS_H
+#define MOBIUS_PYTHON_FILESYSTEM_FILESYSTEM_HFS_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
@@ -32,4 +32,8 @@ typedef struct
 
 extern PyTypeObject filesystem_filesystem_hfs_t;
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// Helper functions
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+
 #endif
