@@ -28,13 +28,16 @@
 #include "core/module.h"
 #include "crypt/module.h"
 #include "database/module.h"
+#include "decoder/module.h"
 #include "disk/module.h"
 #include "filesystem/module.h"
 #include "forensics/module.h"
 #include "imagefile/module.h"
 #include "io/module.h"
+#include "model/module.h"
 #include "partition/module.h"
 #include "system/module.h"
+#include "turing/module.h"
 #include <mobius/exception.inc>
 #include <stdexcept>
 
@@ -84,6 +87,9 @@ initmobius ()
   PyObject *database_module = new_database_module ();
   PyModule_AddObject (mobius_module, "database", database_module);
 
+  PyObject *decoder_module = new_decoder_module ();
+  PyModule_AddObject (mobius_module, "decoder", decoder_module);
+
   PyObject *disk_module = new_disk_module ();
   PyModule_AddObject (mobius_module, "disk", disk_module);
 
@@ -99,12 +105,18 @@ initmobius ()
   PyObject *io_module = new_io_module ();
   PyModule_AddObject (mobius_module, "io", io_module);
 
+  PyObject *model_module = new_model_module ();
+  PyModule_AddObject (mobius_module, "model", model_module);
+
   PyObject *partition_module = new_partition_module ();
   PyModule_AddObject (mobius_module, "partition", partition_module);
 
   PyObject *system_module = new_system_module ();
   PyModule_AddObject (mobius_module, "system", system_module);
 
+  PyObject *turing_module = new_turing_module ();
+  PyModule_AddObject (mobius_module, "turing", turing_module);
+
   // deprecated: this types must be enclosed in submodules
   Py_INCREF (&api_dataholder_t);
   PyModule_AddObject (mobius_module, "dataholder", (PyObject *) &api_dataholder_t);
